@@ -4,10 +4,14 @@ import logging
 from django.conf import settings
 from django.contrib.auth import get_user_model
 
+from mitol.common.utils.config import get_missing_settings
 from mitol.common.utils.datetime import now_in_utc
 from mitol.google_sheets.exceptions import SheetRowParsingException
 from mitol.google_sheets.sheet_handler_api import GoogleSheetsChangeRequestHandler
 from mitol.google_sheets.utils import ResultType, RowResult
+from mitol.google_sheets_refunds.constants import (
+    REQUIRED_GOOGLE_SHEETS_REFUNDS_SETTINGS,
+)
 from mitol.google_sheets_refunds.hooks import get_plugin_manager
 from mitol.google_sheets_refunds.models import RefundRequest
 from mitol.google_sheets_refunds.utils import RefundRequestRow, refund_sheet_config
@@ -30,6 +34,18 @@ class RefundRequestHandler(GoogleSheetsChangeRequestHandler):
             request_model_cls=RefundRequest,
         )
 
+    def is_configured(self):
+        """
+        Checks for required settings.
+
+        Returns:
+            bool: false if required settings are missing
+        """
+
+        return super().is_configured() and not get_missing_settings(
+            REQUIRED_GOOGLE_SHEETS_REFUNDS_SETTINGS
+        )
+
     def process_row(self, row_index, row_data):
         """
         Ensures that the given spreadsheet row is correctly represented in the database,
@@ -104,3 +120,27 @@ class RefundRequestHandler(GoogleSheetsChangeRequestHandler):
             result_type=result_type,
             message=message,
         )
+
+    def _int_filter_row(self, row_tuple):
+        """Performs row filtering according to the rules noted in filter_ignored_rows"""
+        try:
+            parsed_data = RefundRequestRow.parse_raw_data(*row_tuple)
+            return not (
+                parsed_data.skip_row or parsed_data.refund_complete_date is not None
+            )
+        except Exception:
+            return True
+
+    def filter_ignored_rows(self, enumerated_rows):
+        """
+        Filters skippable rows in the sheet. A row is skippable if these conditions is met:
+        - Ignore flag is set to TRUE
+
+        Args:
+            enumerated_rows (Iterable[Tuple[int, List[str]]]): Row indices paired with a list of strings
+                representing the data in each row
+
+        Returns:
+            Iterable[Tuple[int, List[str]]]: Iterable of data rows without the ones that should be ignored.
+        """
+        return filter(self._int_filter_row, enumerated_rows)
